package DBI::Easy::Test::Contact;

use Class::Easy;

use base qw(DBI::Easy::Record);

1;